@@ -53,6 +53,7 @@ var CommonFlags = flag.Set{
 	flag.BuildOnly(),
 	flag.BpDockerHost(),
 	flag.BpVolume(),
+	flag.RecreateBuilder(),
 	flag.Yes(),
 	flag.VMSizeFlags,
 	flag.StringArray{
@@ -298,13 +299,14 @@ func DeployWithConfig(ctx context.Context, appConfig *appconfig.Config, forceYes
 
 	httpFailover := flag.GetHTTPSFailover(ctx)
 	usingWireguard := flag.GetWireguard(ctx)
+	recreateBuilder := flag.GetRecreateBuilder(ctx)
 
 	// Fetch an image ref or build from source to get the final image reference to deploy
-	img, err := determineImage(ctx, appConfig, usingWireguard)
+	img, err := determineImage(ctx, appConfig, usingWireguard, recreateBuilder)
 	if err != nil && usingWireguard && httpFailover {
 		span.SetAttributes(attribute.String("builder.failover_error", err.Error()))
 		span.AddEvent("using http failover")
-		img, err = determineImage(ctx, appConfig, false)
+		img, err = determineImage(ctx, appConfig, false, recreateBuilder)
 	}
 
 	if err != nil {
